# LeProHQpy

(Un-)Polarized Lepto-Production of Heavy Quarks.

This is the stand-alone Python wrapper for the fully-inclusive coefficient functions.

To see this implementation of the coefficient functions in action, i.e. actual structure functions, please use [yadism](https://n3pdf.github.io/yadism/).

